==> kdevelop-4.5.80.tar.xz: kdevelop-4.5.80/projectbuilders/makebuilder/kdevmakebuilder.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Make Project Builder
Name[bs]=Napravi graditelja projekta
Name[ca]=Constructor de projecte Make
Name[ca@valencia]=Constructor de projecte Make
Name[cs]=Překladač projektů Make
Name[da]=Bygning af Make-projekter
Name[de]=Ersteller für Make-Projekte
Name[el]=Κατασκευαστής έργου Make
Name[en_GB]=Make Project Builder
Name[es]=Constructor de proyecto Make
Name[et]=Make'i projektiehitaja
Name[fi]=Make-projektikäännin
Name[fr]=Constructeur de projets Make
Name[ga]=Tógálaí Tionscadal Make
Name[gl]=Construtor de proxecto con Make
Name[hu]=Make projektfordító
Name[it]=Compilatore progetto Make
Name[ja]=Make プロジェクトビルダー
Name[kk]=Make жоба құрастырғышы
Name[nb]=Make prosjektbygger
Name[nds]=Make-Projektbuumoduul
Name[nl]=Make-projectbouwer
Name[pl]=Budowanie za pomocą make
Name[pt]=Construtor de Projectos do Make
Name[pt_BR]=Compilador de projeto do Make
Name[ru]=Сборщик проектов Make
Name[sk]=Prekladač projektov Make
Name[sl]=Izgrajevalnik projekta Make
Name[sv]=Make-projektbyggverktyg
Name[tr]=Make Proje Oluşturucu
Name[ug]=Make قۇرۇلۇش ياسىغۇچ
Name[uk]=Інструмент збирання проектів Make
Name[x-test]=xxMake Project Builderxx
Name[zh_CN]=Make 工程构建器
Name[zh_TW]=Make 專案建立器
GenericName=Project Builder
GenericName[bs]=Graditelj projekta
GenericName[ca]=Constructor de projectes
GenericName[ca@valencia]=Constructor de projectes
GenericName[cs]=Překladač projektů
GenericName[da]=Bygning af projekter
GenericName[de]=Projektersteller
GenericName[el]=Κατασκευαστής έργου
GenericName[en_GB]=Project Builder
GenericName[es]=Constructor de proyectos
GenericName[et]=Projektiehitaja
GenericName[fi]=Projektikäännin
GenericName[fr]=Constructeur de projets
GenericName[ga]=Tógálaí Tionscadal
GenericName[gl]=Construtor de proxectos
GenericName[hu]=Projektfordító
GenericName[it]=Compilatore progetto
GenericName[ja]=プロジェクトビルダー
GenericName[kk]=Жоба құрастырғышы
GenericName[km]=កម្មវិធី​ស្ថាបនា​គម្រោង
GenericName[nb]=Prosjektbygger
GenericName[nds]=Projektbuumoduul
GenericName[nl]=Projectbouwer
GenericName[pl]=Budowanie projektu
GenericName[pt]=Construtor de Projectos
GenericName[pt_BR]=Compilador de projetos
GenericName[ru]=Сборщик проектов
GenericName[sk]=Prekladač projektov
GenericName[sl]=Izgrajevalnik projektov
GenericName[sv]=Projektbyggverktyg
GenericName[tr]=Proje Oluşturucu
GenericName[ug]=قۇرۇلۇش ياسىغۇچ
GenericName[uk]=Збирання проектів
GenericName[x-test]=xxProject Builderxx
GenericName[zh_CN]=工程构建器
GenericName[zh_TW]=專案編譯器
Comment=KDevelop Make Builder
Comment[bs]=KDevelop Make izgraditelj
Comment[ca]=Constructor KDevelop Make
Comment[ca@valencia]=Constructor KDevelop Make
Comment[da]=Make-bygger til KDevelop
Comment[de]=Make-Builder von KDevelop
Comment[el]=Κατασκευαστής Make του KDevelop
Comment[en_GB]=KDevelop Make Builder
Comment[es]=Constructor make de KDevelop
Comment[et]=KDevelopi Make ehitaja
Comment[fi]=KDevelop Make-käännin
Comment[fr]=Constructeur Make pour KDevelop
Comment[ga]=Tógálaí Make le haghaidh KDevelop
Comment[gl]=Axudante para o Make de KDevelop
Comment[hi]=के-डेवलप मेक बिल्डर
Comment[hne]=के-डेवलप मेक बिल्डर
Comment[hu]=KDevelop Make fordító
Comment[it]=Compilatore Make di KDevelop
Comment[ja]=KDevelop Make ビルダー
Comment[kk]=KDevelop-тың Make құрастырғышы
Comment[ko]=KDevelop Make 생성기
Comment[lv]=KDevelop make būvētājs
Comment[nb]=KDevelop Make-bygger
Comment[nds]=Make-Buuwarktüüch vun KDevelop
Comment[ne]=केडीई विकास निर्माण विकासकर्ता
Comment[nl]=KDevelop Make-bouwer
Comment[pa]=KDevelop Make ਬਿਲਡਰ
Comment[pl]=KDevelop: budowanie za pomocą make
Comment[pt]=Construtor do Make para o KDevelop
Comment[pt_BR]=Compilador do Make para o KDevelop
Comment[ru]=Сборщик Make для KDevelop
Comment[sk]=Prekladač KDevelop Make
Comment[sl]=Izgrajevalnik Make za KDevelop
Comment[sv]=KDevelop byggverktyg för Make
Comment[tr]=KDevelop Make Builder
Comment[ug]=KDevelop نىڭ Make نى ياسىغۇچ
Comment[uk]=Збирач Make для KDevelop
Comment[x-test]=xxKDevelop Make Builderxx
Comment[zh_CN]=KDevelop Make 构建器
Comment[zh_TW]=KDevelop Make 建立器
Icon=gear
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevmakebuilder
X-KDE-PluginInfo-Name=KDevMakeBuilder
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IMakeBuilder
X-KDevelop-IRequired=org.kdevelop.IOutputView
X-KDevelop-Mode=NoGUI

==> kdevelop-4.5.90.tar.xz: kdevelop-4.5.90/projectbuilders/makebuilder/kdevmakebuilder.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Make Project Builder
Name[bs]=Napravi graditelja projekta
Name[ca]=Constructor de projecte Make
Name[ca@valencia]=Constructor de projecte Make
Name[cs]=Překladač projektů Make
Name[da]=Bygning af Make-projekter
Name[de]=Ersteller für Make-Projekte
Name[el]=Κατασκευαστής έργου Make
Name[en_GB]=Make Project Builder
Name[es]=Constructor de proyecto Make
Name[et]=Make'i projektiehitaja
Name[fi]=Make-projektikäännin
Name[fr]=Constructeur de projets Make
Name[ga]=Tógálaí Tionscadal Make
Name[gl]=Construtor de proxecto con Make
Name[hu]=Make projektfordító
Name[it]=Compilatore progetto Make
Name[ja]=Make プロジェクトビルダー
Name[kk]=Make жоба құрастырғышы
Name[nb]=Make prosjektbygger
Name[nds]=Make-Projektbuumoduul
Name[nl]=Make-projectbouwer
Name[pl]=Budowanie za pomocą make
Name[pt]=Construtor de Projectos do Make
Name[pt_BR]=Compilador de projeto do Make
Name[ru]=Сборщик проектов Make
Name[sk]=Prekladač projektov Make
Name[sl]=Izgrajevalnik projekta Make
Name[sv]=Make-projektbyggverktyg
Name[tr]=Make Proje Oluşturucu
Name[ug]=Make قۇرۇلۇش ياسىغۇچ
Name[uk]=Інструмент збирання проектів Make
Name[x-test]=xxMake Project Builderxx
Name[zh_CN]=Make 工程构建器
Name[zh_TW]=Make 專案建立器
GenericName=Project Builder
GenericName[bs]=Graditelj projekta
GenericName[ca]=Constructor de projectes
GenericName[ca@valencia]=Constructor de projectes
GenericName[cs]=Překladač projektů
GenericName[da]=Bygning af projekter
GenericName[de]=Projektersteller
GenericName[el]=Κατασκευαστής έργου
GenericName[en_GB]=Project Builder
GenericName[es]=Constructor de proyectos
GenericName[et]=Projektiehitaja
GenericName[fi]=Projektikäännin
GenericName[fr]=Constructeur de projets
GenericName[ga]=Tógálaí Tionscadal
GenericName[gl]=Construtor de proxectos
GenericName[hu]=Projektfordító
GenericName[it]=Compilatore progetto
GenericName[ja]=プロジェクトビルダー
GenericName[kk]=Жоба құрастырғышы
GenericName[km]=កម្មវិធី​ស្ថាបនា​គម្រោង
GenericName[nb]=Prosjektbygger
GenericName[nds]=Projektbuumoduul
GenericName[nl]=Projectbouwer
GenericName[pl]=Budowanie projektu
GenericName[pt]=Construtor de Projectos
GenericName[pt_BR]=Compilador de projetos
GenericName[ru]=Сборщик проектов
GenericName[sk]=Prekladač projektov
GenericName[sl]=Izgrajevalnik projektov
GenericName[sv]=Projektbyggverktyg
GenericName[tr]=Proje Oluşturucu
GenericName[ug]=قۇرۇلۇش ياسىغۇچ
GenericName[uk]=Збирання проектів
GenericName[x-test]=xxProject Builderxx
GenericName[zh_CN]=工程构建器
GenericName[zh_TW]=專案編譯器
Comment=KDevelop Make Builder
Comment[bs]=KDevelop Make izgraditelj
Comment[ca]=Constructor Make del KDevelop
Comment[ca@valencia]=Constructor KDevelop Make
Comment[da]=Make-bygger til KDevelop
Comment[de]=Make-Builder von KDevelop
Comment[el]=Κατασκευαστής Make του KDevelop
Comment[en_GB]=KDevelop Make Builder
Comment[es]=Constructor make de KDevelop
Comment[et]=KDevelopi Make ehitaja
Comment[fi]=KDevelop Make-käännin
Comment[fr]=Constructeur Make pour KDevelop
Comment[ga]=Tógálaí Make le haghaidh KDevelop
Comment[gl]=Axudante para o Make de KDevelop
Comment[hi]=के-डेवलप मेक बिल्डर
Comment[hne]=के-डेवलप मेक बिल्डर
Comment[hu]=KDevelop Make fordító
Comment[it]=Compilatore Make di KDevelop
Comment[ja]=KDevelop Make ビルダー
Comment[kk]=KDevelop-тың Make құрастырғышы
Comment[ko]=KDevelop Make 생성기
Comment[lv]=KDevelop make būvētājs
Comment[nb]=KDevelop Make-bygger
Comment[nds]=Make-Buuwarktüüch vun KDevelop
Comment[ne]=केडीई विकास निर्माण विकासकर्ता
Comment[nl]=KDevelop Make-bouwer
Comment[pa]=KDevelop Make ਬਿਲਡਰ
Comment[pl]=KDevelop: budowanie za pomocą make
Comment[pt]=Construtor do Make para o KDevelop
Comment[pt_BR]=Compilador do Make para o KDevelop
Comment[ru]=Сборщик Make для KDevelop
Comment[sk]=Prekladač KDevelop Make
Comment[sl]=Izgrajevalnik Make za KDevelop
Comment[sv]=KDevelop byggverktyg för Make
Comment[tr]=KDevelop Make Builder
Comment[ug]=KDevelop نىڭ Make نى ياسىغۇچ
Comment[uk]=Збирач Make для KDevelop
Comment[x-test]=xxKDevelop Make Builderxx
Comment[zh_CN]=KDevelop Make 构建器
Comment[zh_TW]=KDevelop Make 建立器
Icon=gear
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevmakebuilder
X-KDE-PluginInfo-Name=KDevMakeBuilder
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IMakeBuilder
X-KDevelop-IRequired=org.kdevelop.IOutputView
X-KDevelop-Mode=NoGUI
